<?php

/**
 * Defines the admin-specific functionality of the plugin.
 *
 * @since      1.0
 */
	 
class SimpleForm_Submissions_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0
	 */
	
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0
	 */
	
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0
	 */
	
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

    /**
     * Add new submenu page to Contact admin menu.
     *
     * @since    1.0
     */  
     
    public function admin_menu() {
	    
      $settings = get_option('sform_settings');
      $data_storing = ! empty( $settings['data_storing'] ) ? esc_attr($settings['data_storing']) : 'true';	

      if ( $data_storing == 'true') {
	    global $sform_entrie_page;
        $sform_entrie_page = add_submenu_page(null, __('View Request', 'simpleform-contact-form-submissions'), __('View Request', 'simpleform-contact-form-submissions'), 'activate_plugins', 'sform-entrie', array ($this, 'view_sform_entrie') );
      }

   }
  
    /**
     * Render the submitted message page for this plugin.
     *
     * @since    1.0
     */
     
    public function view_sform_entrie() {
      
      include_once( 'partials/message.php' );
    }

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0
	 */
    
    public function enqueue_styles($hook) {

     global $sform_submissions_page;
	 global $sform_entrie_page;
	 if( $hook != $sform_submissions_page && $hook != $sform_entrie_page )
	 return;
	 
	 wp_enqueue_style('sform_submissions_style', plugins_url('/css/admin.css',__FILE__));
	      
	}
	
	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0
	 */
	
	public function enqueue_scripts($hook){
	    		
     global $settings_page;
     global $sform_entrie_page;

	 if( $hook != $settings_page && $hook != $sform_entrie_page )
	 return;

     wp_enqueue_script( 'sform_submissions', plugin_dir_url( __FILE__ ) . 'js/admin.js', array( 'jquery' ), $this->version, false );
     wp_localize_script( 'sform_submissions', 'sform_submissions_object', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'enable' => esc_html__( 'Check if you want to add the submissions list in the dashboard and enable the form data storing', 'simpleform-contact-form-submissions' ), 'disable' => esc_html__( 'Uncheck if you want to remove the submissions list from the dashboard and disable the form data storing', 'simpleform-contact-form-submissions' ) )); 
	      
	}
	
	/**
	 * Add submissions related fields in settings page.
	 *
	 * @since    1.0
	 */
	
    public function submissions_settings_fields( $id, $extra_option ) {
	    
	 $main_settings = get_option('sform_settings'); 

	 if ( $id == '1' ) { 
     $settings = $main_settings; 
     $attributes = get_option('sform_attributes');
     } else { 
     $settings_option = get_option('sform_'. $id .'_settings');
     $settings = $settings_option != false ? $settings_option : get_option('sform_settings');
     $attributes_option = get_option('sform_'.$id.'_attributes');
     $attributes = $attributes_option != false ? $attributes_option : get_option('sform_attributes');     
	 }
	
     $data_storing = ! empty( $settings['data_storing'] ) ? esc_attr($settings['data_storing']) : 'true';
     $ip_storing = ! empty( $settings['ip_storing'] ) ? esc_attr($settings['ip_storing']) : 'true';
     $columns = ! empty( $settings['data_columns'] ) ? esc_attr($settings['data_columns']) : 'subject,firstname,message,mail,date';	
     $counter = ! empty( $main_settings['counter'] ) ? esc_attr($main_settings['counter']) : 'true';
     $deleting_messages = ! empty( $main_settings['deleting_messages'] ) ? esc_attr($main_settings['deleting_messages']) : 'false';
     $name_field = ! empty( $attributes['name_field'] ) ? esc_attr($attributes['name_field']) : 'visible';
     $lastname_field = ! empty( $attributes['lastname_field'] ) ? esc_attr($attributes['lastname_field']) : 'hidden';
     $email_field = ! empty( $attributes['email_field'] ) ? esc_attr($attributes['email_field']) : 'visible';
     $phone_field = ! empty( $attributes['phone_field'] ) ? esc_attr($attributes['phone_field']) : 'hidden';
     
     global $wpdb; 
     $count_forms = $wpdb->get_var("SELECT COUNT(*) FROM {$wpdb->prefix}sform_shortcodes WHERE id != '1'");
     ?>
		
     <tr><th class="heading" colspan="2"><span><?php esc_html_e( 'Data Storing Options','simpleform-contact-form-submissions') ?></span></th></tr>	
	 
	 <tr><th id="thstoring" class="option first"><span><?php esc_html_e('Data Storing', 'simpleform-contact-form-submissions' ) ?></span></th><td id="tdstoring" class="checkbox notes first"><label for="data-storing"><input type="checkbox" class="sform" name="data-storing" id="data-storing" value="true" <?php checked( $data_storing, 'true'); ?>><?php _e( 'Enable the form data storing in the database (data will be included only within the notification email if unchecked)', 'simpleform-contact-form-submissions' ); ?></label><p id="storing-description" class="description"><?php if ($data_storing !='true') { esc_html_e('Check if you want to add the submissions list in the dashboard and enable the form data storing', 'simpleform-contact-form-submissions' ); } else { esc_html_e('Uncheck if you want to remove the submissions list from the dashboard and disable the form data storing', 'simpleform-contact-form-submissions' ); } ?></p></td></tr>
						  
	 <tr class="trstoring <?php if ($data_storing !='true') {echo 'unseen';} else {echo 'visible';} ?>"><th class="option"><span><?php esc_html_e('IP Address Storing', 'simpleform-contact-form-submissions' ) ?></span></th><td class="checkbox"><label for="ip-storing"><input id="ip-storing" name="ip-storing" type="checkbox" class="sform" value="true" <?php checked( $ip_storing, 'true'); ?> ><?php _e( 'Enable IP address storing in the database', 'simpleform-contact-form-submissions' ); ?></label></td></tr>

     <tr class="trstoring <?php if ($data_storing !='true') {echo 'unseen';} else {echo 'visible';} ?>" ><th class="option"><span><?php esc_html_e( 'Visible Data Columns', 'simpleform-contact-form-submissions' ) ?></span></th><td class="checkbox notes"><label for="id"><input type="checkbox" name="columns[]" id="id" class="sform" value="id" <?php if (strpos($columns,'id') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Request ID', 'simpleform-contact-form-submissions' ); ?></label><label for="subject"><input type="checkbox" name="columns[]" id="subject" class="sform" value="subject" <?php if (strpos($columns,'subject') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Subject', 'simpleform-contact-form-submissions' ); ?></label><?php if ( $name_field != 'hidden' ) { ?><label for="firstname"><input type="checkbox" name="columns[]" id="firstname" class="sform" value="firstname" <?php if (strpos($columns,'firstname') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Name', 'simpleform-contact-form-submissions' ); ?></label><?php } ?><?php if ( $lastname_field != 'hidden' ) { ?><label for="family"><input type="checkbox" name="columns[]" id="family" class="sform" value="family" <?php if (strpos($columns,'family') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Last Name', 'simpleform-contact-form-submissions' ); ?></label><?php } ?><?php if ( $name_field != 'hidden' && $lastname_field != 'hidden' ) { ?><label for="from"><input type="checkbox" name="columns[]" id="from" class="sform" value="from" <?php if (strpos($columns,'from') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Full Name', 'simpleform-contact-form-submissions' ); ?></label><?php } ?><label for="message"><input type="checkbox" name="columns[]" id="message" class="sform" value="message" <?php if (strpos($columns,'message') !== false) { echo 'checked'; }?>><?php esc_html_e( 'Message', 'simpleform-contact-form-submissions' ); ?></label><?php if ( $email_field != 'hidden' ) { ?><label for="mail"><input type="checkbox" name="columns[]" id="mail" class="sform" value="mail" <?php if (strpos($columns,'mail') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Email', 'simpleform-contact-form-submissions' ); ?></label><?php } ?><?php if ( $phone_field != 'hidden' ) { ?><label for="phone"><input type="checkbox" name="columns[]" id="phone" class="sform" value="phone" <?php if (strpos($columns,'phone') !== false) { echo 'checked'; } ?>><?php esc_html_e( 'Phone', 'simpleform-contact-form-submissions' ); ?></label><?php } ?><label for="ip"><input type="checkbox" name="columns[]" id="ip" class="sform" value="ip" <?php if (strpos($columns,'ip') !== false) { echo 'checked'; }?>><?php esc_html_e( 'IP', 'simpleform-contact-form-submissions' ); ?></label><label for="date"><input type="checkbox" name="columns[]" id="date" class="sform" value="date" <?php if (strpos($columns,'date') !== false) { echo 'checked'; }?>><?php esc_html_e( 'Date', 'simpleform-contact-form-submissions' ); ?></label><p class="description"><?php esc_html_e( 'Set the default columns that must be displayed in the submissions list table. You can disable the visible columns at any time via "Screen options"', 'simpleform-contact-form-submissions' ) ?></p></td></tr>

	 <tr <?php if ($count_forms == 0 ) { echo 'class="trstoring '; if ($data_storing !='true') {echo 'unseen"';} else {echo 'visible"';} }?>><th class="option"><span><?php esc_html_e('Unread Count', 'simpleform-contact-form-submissions' ) ?></span></th><td class="checkbox" <?php if ( $id != '1' ) { echo 'style="padding-right: 41px;"'; }?>><label for="counter"><input id="counter" name="counter" type="checkbox" class="sform" value="true" <?php checked( $counter, 'true'); if ( $id != '1' ) { echo 'disabled="disabled"'; }?> ><?php _e( 'Add a notification bubble to admin menu for unread messages', 'simpleform-contact-form-submissions' ); if ($count_forms > 0 ) { ?><span class="head-bracket" style="font-style: italic; font-weight: 400; padding-left: 10px;">(<?php esc_html_e( 'This applies to all forms','simpleform-contact-form-submissions'); ?>)</span> <?php } ?></label><?php if ( $id != '1' ) { ?><a href="<?php echo menu_page_url( 'sform-settings', false ); ?>" style="text-decoration: none; color: #FFF; "><span class="settings-page"><?php esc_html_e( 'Go to main settings for edit', 'simpleform' ) ?></span></a><?php } ?></td></tr>
     
	 <tr><th class="option last"><span><?php esc_html_e('Deleting Messages', 'simpleform-contact-form-submissions' ) ?></span></th><td class="checkbox last" <?php if ( $id != '1' ) { echo 'style="padding-right: 41px;"'; }?>><label for="deleting-data"><input id="deleting-data" name="deleting-data" type="checkbox" class="sform" value="false" <?php checked( $deleting_messages, 'true'); if ( $id != '1' ) { echo 'disabled="disabled"'; } ?> ><?php _e( 'Delete messages from the database when uninstalling the plugin', 'simpleform-contact-form-submissions' ); if ($count_forms > 0 ) { ?><span class="head-bracket" style="font-style: italic; font-weight: 400; padding-left: 10px;">(<?php esc_html_e( 'This applies to all forms','simpleform-contact-form-submissions'); ?>)</span> <?php } ?></label><?php if ( $id != '1' ) { ?><a href="<?php echo menu_page_url( 'sform-settings', false ); ?>" style="text-decoration: none; color: #FFF; "><span class="settings-page"><?php esc_html_e( 'Go to main settings for edit', 'simpleform' ) ?></span></a><?php } ?></td></tr>
     
    <?php 
    }	

	/**
	 * Add submissions related fields values in the settings options array.
	 *
	 * @since    1.0
	 */
	
    public function add_array_submissions_settings() { 
  
       $id = isset( $_POST['form-id'] ) ? absint($_POST['form-id']) : '1';
       $main_settings = get_option('sform_settings'); 
      
       $data_storing = isset($_POST['data-storing']) ? 'true' : 'false';
       $ip_storing = isset($_POST['ip-storing']) ? 'true' : 'false';
       $columns = isset($_POST['columns']) ? esc_html(trim(implode(",", $_POST['columns']))) : '';
       
       global $wpdb;
       
       if ( $data_storing == 'false' )  { 
	     $ip_storing = 'false'; 
	     $columns = '';
	     $wpdb->query( $wpdb->prepare("UPDATE {$wpdb->prefix}sform_submissions SET listable = '0' WHERE form = %d", $id) );   
	   }
       else {
	     $wpdb->query( $wpdb->prepare("UPDATE {$wpdb->prefix}sform_submissions SET listable = '1' WHERE form = %d", $id) );   
	   }
       
       if ( $id == '1' ) {
         $counter = isset($_POST['counter']) ? 'true' : 'false';
         $deleting_messages = isset($_POST['deleting-data']) ? 'true' : 'false';
         $new_items = array( 'data_storing' => $data_storing, 'ip_storing' => $ip_storing, 'data_columns' => $columns, 'counter' => $counter, 'deleting_messages' => $deleting_messages );
         
         $table = $wpdb->prefix . 'sform_shortcodes';
         // if ( $result = $wpdb->get_results("SHOW TABLES LIKE '".$table."'") ) {
           $ids = $wpdb->get_col("SELECT id FROM `$table` WHERE id != '1'");	
           if ( $ids ) {
             foreach($ids as $id) { 
	         $form_settings = get_option('sform_'. $id .'_settings');
             if ( $form_settings != false ) {
			   $form_settings['counter'] = $counter;
			   $form_settings['deleting_messages'] = $deleting_messages;
               update_option('sform_'. $id .'_settings', $form_settings); 
	         }
             }
           }
        // }
                  
       }
       else {
         $new_items = array( 'data_storing' => $data_storing, 'ip_storing' => $ip_storing, 'data_columns' => $columns, 'counter' => $main_settings['counter'], 'deleting_messages' => $main_settings['deleting_messages'] );
       }
     
       return  $new_items;
       
    }

	/**
	 * Validate submissions related fields in Settings page.
	 *
	 * @since    1.0
	 */
	
    public function validate_submissions_fields(){
	    
       $data_storing = isset($_POST['data-storing']) ? 'true' : 'false';
       $notification = isset($_POST['notification']) ? 'true' : 'false';   
       $columns = isset($_POST['columns']) ? esc_html(trim(implode(",", $_POST['columns']))) : '';
     
       if ( strpos($columns,'firstname') !== false && strpos($columns,'from') !== false ) {
            echo json_encode(array('error' => true, 'update' => false, 'message' => esc_html__('The column Name and the column Full Name cannot both be selected', 'simpleform-contact-form-submissions')  ));
	        exit; 
       }

       if ( strpos($columns,'family') !== false && strpos($columns,'from') !== false ) {
            echo json_encode(array('error' => true, 'update' => false, 'message' => esc_html__('The column Last Name and the column Full Name cannot both be selected', 'simpleform-contact-form-submissions')  ));
	        exit; 
       }
	   
	   if ( $data_storing == 'false' && $notification == 'false' ) {
            echo json_encode(array('error' => true, 'update' => false, 'message' => esc_html__('The Data Storing option and the Enable Notification option cannot both be disabled. Please keep at least one option enabled!', 'simpleform-contact-form-submissions')  ));
	        exit; 
       }
  
    }
	
	/**
	 * Display submissions list in dashboard.
	 *
	 * @since    1.0
	 */

    public function display_submissions_list($id, $shortcode_ids){
    
     $main_settings = get_option('sform_settings'); 

     if ( $id == '' ) {
      $settings = $main_settings;
      $where_form = " WHERE form != '0'";
      $last_message = stripslashes(get_transient('sform_last_message'));

	 } else {
      $settings_option = get_option('sform_'. $id .'_settings');
      $settings = $settings_option != false ? $settings_option : get_option('sform_settings');
      $where_form = " WHERE form = '". $id ."'";
      $last_message = stripslashes(get_transient('sform_last_'.$id.'_message'));
     }
     
     $data_storing = ! empty( $settings['data_storing'] ) ? esc_attr($settings['data_storing']) : 'true';	

     // get all storing options values
     $all_data_storing = array($main_settings['data_storing']);
     global $wpdb;
     $shortcodes_table = $wpdb->prefix . 'sform_shortcodes';
     $ids = $wpdb->get_col("SELECT id FROM `$shortcodes_table` WHERE id != '1'");	 
     if ( $ids ) {
	  foreach ( $ids as $form_id ) {
	  $form_settings = get_option('sform_'.$form_id.'_settings');
      $form_data_storing = $form_settings != false && ! empty( $form_settings['data_storing'] ) ? esc_attr($form_settings['data_storing']) : 'false';
      array_push($all_data_storing, $form_data_storing);
      }
     }
     
     if ( in_array('true',$all_data_storing) ) {	

      if (  $id == '' || in_array($id, $shortcode_ids) ) {
	     
        if ( $id == '' || $data_storing == 'true' )  {
          $table = new SForms_Submissions_List_Table();
          $table->prepare_items();
          $table->views(); 
          ?>
          <form id="submissions-table" method="get"><input type="hidden" name="page" value="<?php echo sanitize_key($_REQUEST['page']) ?>"/>
          <?php $table->search_box( __( 'Search' ), 'simpleform-contact-form-submissions');	
	      $transient_notice = stripslashes(get_transient('sform_action_notice'));
          $notice = $transient_notice != '' ? $transient_notice : '';
          echo $notice; 
          $table->display(); 
          ?></form><?php
        }
        
        else { 
          $admin_notices = ! empty( $main_settings['admin_notices'] ) ? esc_attr($main_settings['admin_notices']) : 'false';	
    	  if ( $admin_notices == 'false' ) {
	   	   $link = '<a href="' . admin_url('admin.php?page=sform-settings') . '&form='. $id . '" target="_blank">' . __( 'form settings', 'simpleform-contact-form-submissions' ) . '</a>';
 	       $notice = '<div class="notice notice-warning is-dismissible"><p>' . sprintf( __( 'By disabling the data storing for this form, you chose to remove the submissions list relating to the form. Go to %s for editing the option.', 'simpleform-contact-form-submissions' ), $link ) .'</p></div>';
echo $notice;
          }
          global $wpdb;
          $table_name = $wpdb->prefix . 'sform_submissions';
          $where_day = 'AND date >= UTC_TIMESTAMP() - INTERVAL 24 HOUR';
          $where_week = 'AND date >= UTC_TIMESTAMP() - INTERVAL 7 DAY';
          $where_month = 'AND date >= UTC_TIMESTAMP() - INTERVAL 30 DAY';
          $where_year = 'AND date >= UTC_TIMESTAMP() - INTERVAL 1 YEAR';
          $count_all = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form AND object != '' AND object != 'not stored'");
          $count_last_day = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_day AND object != '' AND object != 'not stored'");
          $count_last_week = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_week AND object != '' AND object != 'not stored'");
          $count_last_month = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_month AND object != '' AND object != 'not stored'");
          $count_last_year = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_year AND object != '' AND object != 'not stored'");
          $total_received = $count_all;
          ?>
          <div><ul id="submissions-data"><li class="type"><span class="label"><?php esc_html_e( 'Received', 'simpleform' ); ?></span><span class="value"><?php echo $total_received; ?></span></li><li class="type"><span class="label"><?php esc_html_e( 'This Year', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_year; ?></span></li><li class="type"><span class="label"><?php esc_html_e( 'Last Month', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_month; ?></span></li><li class="type"><span class="label"><?php esc_html_e( 'Last Week', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_week; ?></span></li><li><span class="label"><?php esc_html_e( 'Last Day', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_day; ?></span></li></ul></div>
<?php
	      if ( $last_message ) {
	       echo '<div id="last-submission"><h3><span class="dashicons dashicons-buddicons-pm"></span>'.esc_html__('Last Message Received', 'simpleform-contact-form-submissions' ).'</h3>'.$last_message . '</div>'; echo '<div id="submissions-notice" class="unseen"><h3><span class="dashicons dashicons-editor-help"></span>'.esc_html__('Before you go crazy looking for the received messages', 'simpleform-contact-form-submissions' ).'</h3>'.esc_html__('Submissions data is not stored in the WordPress database. Open the General Tab in the Settings page, and check the Data Storing option for enabling the display of messages in the dashboard. By default, only last message is temporarily stored. Therefore, it is recommended that you verify the correct SMTP server configuration in case of use, and always keep the notification email enabled if you want to be sure to receive the messages.', 'simpleform-contact-form-submissions' ).'</div>';
	      }
	      else  {
	       echo '<div id="empty-submission"><h3><span class="dashicons dashicons-info"></span>'.esc_html__('Empty Inbox', 'simpleform-contact-form-submissions' ).'</h3>'.esc_html__('So far, no message has been received yet!', 'simpleform-contact-form-submissions' ).'<p>'.esc_html__('Submissions data is not stored in the WordPress database. Open the General Tab in the Settings page, and check the Data Storing option for enabling the display of messages in the dashboard. By default, only last message is temporarily stored. Therefore, it is recommended that you verify the correct SMTP server configuration in case of use, and always keep the notification email enabled if you want to be sure to receive the messages.', 'simpleform-contact-form-submissions' ).'</div>';
	      }
        }
 
 	  } 
	 
	  else {
       ?>
       <span><?php esc_html_e('It seems the form is no longer available!', 'simpleform' ) ?></span><p><span class="sf button button-primary"><a href="<?php echo menu_page_url( 'sform-submissions', false ); ?>" style="text-decoration: none; color: #FFF; "><?php esc_html_e('Reload the Submissions page','simpleform') ?></a></span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class="sf button button-primary"><a href="<?php echo menu_page_url( 'sform-creation', false ); ?>" style="text-decoration: none; color: #FFF; "><?php esc_html_e('Add New Form','simpleform') ?></a></span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class="sf button button-primary"><a href="<?php echo self_admin_url('widgets.php'); ?>" style="text-decoration: none; color: #FFF; "><?php esc_html_e('Activate SimpleForm Contact Form Widget','simpleform') ?></a></span></p>
     <?php
      }
     
     } 
     
     else {
 
      if ( $id == '' || in_array($id, $shortcode_ids) ) {
      global $wpdb;
      $table_name = $wpdb->prefix . 'sform_submissions';
      $where_day = 'AND date >= UTC_TIMESTAMP() - INTERVAL 24 HOUR';
      $where_week = 'AND date >= UTC_TIMESTAMP() - INTERVAL 7 DAY';
      $where_month = 'AND date >= UTC_TIMESTAMP() - INTERVAL 30 DAY';
      $where_year = 'AND date >= UTC_TIMESTAMP() - INTERVAL 1 YEAR';
      $count_all = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form AND object != '' AND object != 'not stored'");
      $count_last_day = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_day AND object != '' AND object != 'not stored'");
      $count_last_week = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_week AND object != '' AND object != 'not stored'");
      $count_last_month = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_month AND object != '' AND object != 'not stored'");
      $count_last_year = $wpdb->get_var("SELECT COUNT(id) FROM $table_name $where_form $where_year AND object != '' AND object != 'not stored'");
      $total_received = $count_all;
      ?>

      <div><ul id="submissions-data"><li class="type"><span class="label"><?php esc_html_e( 'Received', 'simpleform' ); ?></span><span class="value"><?php echo $total_received; ?></span></li><li class="type"><span class="label"><?php esc_html_e( 'This Year', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_year; ?></span></li><li class="type"><span class="label"><?php esc_html_e( 'Last Month', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_month; ?></span></li><li class="type"><span class="label"><?php esc_html_e( 'Last Week', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_week; ?></span></li><li><span class="label"><?php esc_html_e( 'Last Day', 'simpleform' ); ?></span><span class="value"><?php echo $count_last_day; ?></span></li></ul></div>
<?php
	  if ( $last_message ) {
	  echo '<div id="last-submission"><h3><span class="dashicons dashicons-buddicons-pm"></span>'.esc_html__('Last Message Received', 'simpleform-contact-form-submissions' ).'</h3>'.$last_message . '</div>'; echo '<div id="submissions-notice" class="unseen"><h3><span class="dashicons dashicons-editor-help"></span>'.esc_html__('Before you go crazy looking for the received messages', 'simpleform-contact-form-submissions' ).'</h3>'.esc_html__('Submissions data is not stored in the WordPress database. Open the General Tab in the Settings page, and check the Data Storing option for enabling the display of messages in the dashboard. By default, only last message is temporarily stored. Therefore, it is recommended that you verify the correct SMTP server configuration in case of use, and always keep the notification email enabled if you want to be sure to receive the messages.', 'simpleform-contact-form-submissions' ).'</div>';
	  }
	  else  {
	  echo '<div id="empty-submission"><h3><span class="dashicons dashicons-info"></span>'.esc_html__('Empty Inbox', 'simpleform-contact-form-submissions' ).'</h3>'.esc_html__('So far, no message has been received yet!', 'simpleform-contact-form-submissions' ).'<p>'.esc_html__('Submissions data is not stored in the WordPress database. Open the General Tab in the Settings page, and check the Data Storing option for enabling the display of messages in the dashboard. By default, only last message is temporarily stored. Therefore, it is recommended that you verify the correct SMTP server configuration in case of use, and always keep the notification email enabled if you want to be sure to receive the messages.', 'simpleform-contact-form-submissions' ).'</div>';
	  }
      } else {
      ?>
      <span><?php esc_html_e('It seems the form is no longer available!', 'simpleform' ) ?></span><p><span class="sf button button-primary"><a href="<?php echo menu_page_url( 'sform-submissions', false ); ?>" style="text-decoration: none; color: #FFF; "><?php esc_html_e('Reload the Submissions page','simpleform') ?></a></span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class="sf button button-primary"><a href="<?php echo menu_page_url( 'sform-creation', false ); ?>" style="text-decoration: none; color: #FFF; "><?php esc_html_e('Add New Form','simpleform') ?></a></span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class="sf button button-primary"><a href="<?php echo self_admin_url('widgets.php'); ?>" style="text-decoration: none; color: #FFF; "><?php esc_html_e('Activate SimpleForm Contact Form Widget','simpleform') ?></a></span></p>
      <?php
     }
     }
	
    }

	/**
	 * Add screen option tab.
	 *
	 * @since    1.0
	 */

    public function submissions_table_options() {
	
	global $sform_submissions_page;
	add_action("load-$sform_submissions_page", array ($this, 'sforms_submissions_list_options') );
    
    }

	/**
	 * Setup function that registers the screen option.
	 *
	 * @since    1.0
	 */

    public function sforms_submissions_list_options() {
	    
      $id = isset( $_REQUEST['form'] ) ? absint($_REQUEST['form']) : '';
     
      if ( $id == '' || $id == '1' ) {
        $settings = get_option('sform_settings');
      } else {
        $settings_option = get_option('sform_'. $id .'_settings');
        $settings = $settings_option != false ? $settings_option : get_option('sform_settings');
      }
      
      $data_storing = ! empty( $settings['data_storing'] ) ? esc_attr($settings['data_storing']) : 'true';
      global $wpdb; 
      $table_name = "{$wpdb->prefix}sform_shortcodes"; 
      $shortcode_ids = $wpdb->get_col( "SELECT id FROM $table_name" );

      if ( $data_storing == 'true' && ( $id == '' || in_array($id, $shortcode_ids) ) ) {
	      
      global $table;
      global $sform_submissions_page;
      $screen = get_current_screen();      
           
      if(!is_object($screen) || $screen->id != $sform_submissions_page)
      return;
      $option = 'per_page';
      $args = array( 'label' => esc_attr__('Number of submissions per page', 'simpleform-contact-form-submissions'),'default' => 20,'option' => 'edit_submission_per_page');
      
      add_screen_option( $option, $args );
      $table = new SForms_Submissions_List_Table(); 
      
     }
  
    }

	/**
	 * Save screen options.
	 *
	 * @since    1.0
	 */

    public function submissions_screen_option($status, $option, $value) {
      
     if ( 'edit_submission_per_page' == $option ) return $value;
     return $status;
    
    }
    
	/**
	 * Register a post type for change the pagination in Screen Options tab.
	 *
	 * @since    1.3
	 */

    public function submission_post_type() {
	
	    $args = array();
	    register_post_type( 'submission', $args );
	    
    }
	
	/**
	 * Render the meta box in the submitted message page.
	 *
	 * @since    1.0
	 */
	
    public function sform_entrie_meta_box_handler($item) {
	    
     ?>
	 <div class="datarow">
	 <div class="thdata first"><?php esc_html_e('From', 'simpleform-contact-form-submissions' ) ?></div>
	 <div class="tddata first"><?php
	    $requester_id = esc_attr($item['requester_id']); 
        if ( isset($requester_id) && $requester_id != 0 ) {
	    $user_info = get_user_by( 'id', $requester_id );
	    $page_user = get_edit_user_link( $requester_id );
		$user_firstname = ! empty($user_info->first_name) ? $user_info->first_name : $user_info->display_name;
		$user_lastname = ! empty($user_info->last_name) ? $user_info->last_name : '';
	    $firstname = $item['name'] != '' && $item['name'] != 'not stored' ? esc_attr($item['name']) : $user_firstname;	    
	    $lastname = $item['lastname'] != '' && $item['lastname'] != 'not stored' ? esc_attr($item['lastname']) : $user_lastname;
        $request_author = trim($firstname.' '.$lastname). ' [ <a href="'.$page_user.'" target="_blank" class="nodecoration">'.$user_info->user_login.'</a> ]<br>'.esc_html__('Registered user', 'simpleform-contact-form-submissions' );
	    }
        else {
	    $firstname = $item['name'] != '' && $item['name'] != 'not stored' ? esc_attr($item['name']) : '';
	    $lastname = $item['lastname'] != '' && $item['lastname'] != 'not stored' ? esc_attr($item['lastname']) : '';
	    if ( !empty($firstname) || !empty($lastname) ):
	    $request_author =  trim($firstname.' '.$lastname) . '<br>'.esc_html__('Anonymous user', 'simpleform-contact-form-submissions' );
	    else:
	    $request_author =  esc_html__('Anonymous user', 'simpleform-contact-form-submissions' );
	    endif;
        }
	    echo $request_author; ?></div>	 
	 </div>
	 
	 <?php
	 $email = $item['email'] != '' && $item['email'] != 'not stored' ? esc_attr($item['email']) : '';
     if ( ! empty($email) ) { ?>
	 <div class="datarow">
     <div class="thdata"><?php esc_html_e('Email', 'simpleform-contact-form-submissions' ) ?></div>		
	 <div class="tddata"><?php echo $email ?></div>
	 </div>
   	 <?php }	 
	 
     global $wpdb;
     $form = $wpdb->get_var($wpdb->prepare("SELECT form FROM {$wpdb->prefix}sform_submissions WHERE id = %d", $item['id']));
     $attributes_option = get_option('sform_'. $form .'_attributes');
     $attributes = $attributes_option != false ? $attributes_option : get_option('sform_attributes');     
     
     $phone_field = ! empty( $attributes['phone_field'] ) ? esc_attr($attributes['phone_field']) : 'hidden';

	 $phone = $item['phone'] != '' && $item['phone'] != 'not stored' ? esc_attr($item['phone']) : '';
     if ( ! empty($phone) ) { 
     ?>
	 <div class="datarow">
	 <div class="thdata"><?php esc_html_e('Phone', 'simpleform-contact-form-submissions' ) ?></div>
	 <div class="tddata"><?php echo $phone ?></div>
	 </div>
	 <?php } ?>	 	 
	 
	 <div class="datarow">
	 <div class="thdata"><?php esc_html_e('Date', 'simpleform-contact-form-submissions' ) ?></div>
	 <div class="tddata"><?php $tzcity = get_option('timezone_string'); $tzoffset = get_option('gmt_offset');
       if ( ! empty($tzcity))  { 
       $current_time_timezone = date_create('now', timezone_open($tzcity));
       $timezone_offset =  date_offset_get($current_time_timezone);
       $submission_timestamp = strtotime(esc_attr($item['date'])) + $timezone_offset; 
       }
       else { 
       $timezone_offset =  $tzoffset * 3600;
       $submission_timestamp = strtotime(esc_attr($item['date'])) + $timezone_offset;  
       }
       /* translators: It is used to indicate the time */
       $at = esc_html__('at', 'simpleform-contact-form-submissions');
       echo date_i18n(get_option('date_format'),$submission_timestamp).' '.$at.' '.date_i18n(get_option('time_format'),$submission_timestamp );?>
     </div>
	 </div>
	 
	 <?php     
	 $ip_address = $item['ip'] != '' && $item['ip'] != 'not stored' ? esc_attr($item['ip']) : '';
     if ( ! empty($ip_address) ) { 
     ?>
	 <div class="datarow">
	 <div class="thdata"><?php esc_html_e('IP', 'simpleform-contact-form-submissions' ) ?></div>
	 <div class="tddata"><?php echo $ip_address ?></div>
	 </div>
	 <?php }
	 
	 $subject = $item['subject'] != '' && $item['subject'] != 'not stored' ? esc_attr($item['subject']) : '';
     if ( ! empty($subject) ) { ?>
	 <div class="datarow">
	 <div class="thdata"><?php esc_html_e('Subject', 'simpleform-contact-form-submissions' ) ?></div>
	 <div class="tddata"><span id="subject-input"><?php echo $subject ?></span></div>	
   	 </div>
   	 <?php } ?>
   	 
	 <div class="datarow">
     <div class="thdata"><?php esc_html_e('Message', 'simpleform-contact-form-submissions' ) ?></div>
     <div class="tddata"><?php echo esc_attr($item['object'])?></div>
     </div>	
 
     <form id="msgstatus" method="post">
     <input type="hidden" id="message-id" name="message-id" value="<?php echo  $item['id'] ?>">
     <input type="hidden" id="previous-status" name="previous-status" value="<?php echo  $item['status'] ?>">
	 <div class="datarow">
     <div class="thdata last"><?php esc_html_e('Status', 'simpleform-contact-form-submissions' ) ?></div>
     <div class="tddata last"><select name="message-status" id="message-status" class="sform"><option value="" disabled><?php esc_html_e('Mark as', 'simpleform-contact-form-submissions' ) ?></option><option value="new"><?php esc_html_e('unread', 'simpleform-contact-form-submissions' ) ?></option><option value="read" <?php if ( $item['status'] == 'read' || $item['status'] == 'new' ) echo 'selected="selected"'; ?>><?php esc_html_e('read', 'simpleform-contact-form-submissions' ) ?></option><option value="answered" <?php selected( $item['status'], 'answered'); ?>><?php esc_html_e('answered', 'simpleform-contact-form-submissions' ) ?></option><option value="spam" <?php selected( $item['status'], 'spam'); ?>><?php esc_html_e('junk', 'simpleform-contact-form-submissions' ) ?></option><option value="trash" <?php selected( $item['status'], 'trash'); ?>><?php esc_html_e('trashed', 'simpleform-contact-form-submissions' ) ?></option></select><span class="message unseen"></span><?php  wp_nonce_field( 'ajax-verification-nonce', 'verification_nonce'); ?></div>
     </div>	
     </form>

 	 <?php
    
    }
    
	/**
	 * Edit message status
	 *
	 * @since    1.6
	 */
	
    public function edit_message_status() {

      if( 'POST' !== $_SERVER['REQUEST_METHOD'] ) {	die ( 'Security checked!'); }
      if ( ! wp_verify_nonce( $_POST['verification_nonce'], "ajax-verification-nonce")) { exit("Security checked!"); }   
      if ( ! current_user_can('update_plugins')) { exit("Security checked!"); }   
   
      else {

       $id = isset( $_POST['message-id'] ) ? absint($_POST['message-id']) : '';
       $previous_status = isset( $_POST['previous-status'] ) ? sanitize_text_field($_POST['previous-status']) : 'read';
       $status = isset($_POST['message-status']) ? sanitize_text_field($_POST['message-status']) : 'read';
       global $wpdb; 
       $table = "{$wpdb->prefix}sform_submissions"; 
       $ids = $wpdb->get_col( "SELECT id FROM $table" );
       
       if ( !empty($id) && in_array($id,$ids) && in_array($status, array('new','read','answered','spam','trash')) ) { 
          $update = $wpdb->update($table, array('status' => $status ), array('id' => $id));
	     
	      if ( $update ) {
		    $msg = '';
		    if ( $previous_status != 'trash' && $status == 'spam' ) {
			   if (has_filter('akismet_submit_spam')) {
               $msg = apply_filters( 'akismet_submit_spam', $id, $msg );
               } 
            }   
		    if ( $previous_status == 'spam' && $status != 'trash' ) {
               if (has_filter('akismet_submit_ham')) {
               $msg = apply_filters( 'akismet_submit_ham', $id, $msg );
               } 
            }   
            $message = __('Message status updated', 'simpleform-contact-form-submissions' ) . $msg;
		    if ( $status == 'new' ) {    
	           echo json_encode(array('error' => false, 'bubble' => true, 'message' => $message ));
	           exit;
	        }
	        else {    
	           echo json_encode(array('error' => false, 'bubble' => false, 'message' => $message ));
	           exit;
	        }  
	      }
	      else {
            echo json_encode(array('error' => true, 'message' => esc_html__( 'Error occurred message status changing', 'simpleform-contact-form-submissions' ) ));
	        exit;
	      }
       }
    
       else {
          echo json_encode(array('error' => true, 'message' => esc_html__( 'Error occurred message status changing', 'simpleform-contact-form-submissions' ) ));
	      exit;
       }
      
       die();
	      
      }

    }
    
 	/**
	 * Fallback for database table updating if plugin is already active.
	 *
	 * @since    1.4
	 */
    
    public function simpleform_db_version_check() {
    
       $current_version = SIMPLEFORM_SUBMISSIONS_DB_VERSION;
       $installed_version = get_option('sform_sub_db_version');
       
       if ( $installed_version != $current_version ) {
        require_once SIMPLEFORM_SUBMISSIONS_PATH . 'includes/class-activator.php';
	    SimpleForm_Submissions_Activator::change_db();
	    SimpleForm_Submissions_Activator::sform_submissions_settings();
       }

    }

 	/**
	 * Add conditional items into the Bulk Actions dropdown for submissions list.
	 *
	 * @since    1.3
	 */

    public function register_sform_actions($bulk_actions) { 
	    
	    $view = isset($_REQUEST['view']) && in_array($_REQUEST['view'], array('inbox', 'new', 'answered', 'spam', 'trash')) ? $_REQUEST['view'] : 'inbox'; 
	    
	    if ( ! empty($view) && $view == 'trash' ) { 
          $bulk_actions['bulk-untrash'] = __('Restore', 'simpleform-contact-form-submissions');
          $bulk_actions['bulk-delete'] = __('Delete permanently', 'simpleform-contact-form-submissions');
        } 
 	    elseif ( ! empty($view) && $view == 'spam' ) { 
          $bulk_actions['bulk-unspam'] = __('Restore', 'simpleform-contact-form-submissions');
          $bulk_actions['bulk-delete'] = __('Delete permanently', 'simpleform-contact-form-submissions');
        } 
  	    elseif ( ! empty($view) && $view == 'answered' ) { 
        } 
        else { 
          $bulk_actions['bulk-spam'] = __('Mark as Spam', 'simpleform-contact-form-submissions');
          $bulk_actions['bulk-trash'] = __('Move to Trash', 'simpleform-contact-form-submissions');
        } 
        return $bulk_actions;
         
    }
    
 	/**
	 * Add a notification bubble to Contacts menu item.
	 *
	 * @since    1.4
	 */

     public function notification_bubble() {
	  
	  $main_settings = get_option('sform_settings');
      $counter = ! empty( $main_settings['counter'] ) ? esc_attr($main_settings['counter']) : 'true';	
      $form_id = isset( $_REQUEST['form'] ) ? absint($_REQUEST['form']) : '';

      if ( $form_id == '1' ) {
        $settings = $main_settings;
      } else {
        $settings_option = get_option('sform_'. $form_id .'_settings');
        $settings = $settings_option != false ? $settings_option : $main_settings;
      }
      
	  global $wpdb;
      $table_name = $wpdb->prefix . 'sform_submissions';      
      $data_storing = ! empty( $settings['data_storing'] ) ? esc_attr($settings['data_storing']) : 'true';
      // get all storing options values
      $all_data_storing = array($main_settings['data_storing']);
      $shortcodes_table = $wpdb->prefix . 'sform_shortcodes';
      $ids = $wpdb->get_col("SELECT id FROM `$shortcodes_table` WHERE id > '1'");	
      if ( $ids ) {
	    foreach ( $ids as $id ) {
	      $form_settings = get_option('sform_'.$id.'_settings');
          $form_data_storing = $form_settings != false && ! empty( $form_settings['data_storing'] ) ? esc_attr($form_settings['data_storing']) : 'false';
          array_push($all_data_storing, $form_data_storing);
        }
      }
     
      if ( ( $form_id != '' && $data_storing == 'true' && $counter == 'true' ) || ( $form_id == '' && in_array('true',$all_data_storing) && $counter == 'true' ) ):
      
        $id = isset( $_REQUEST['id'] ) ? absint($_REQUEST['id']) : '';   
        if( $form_id != '' ){
          $unread = $wpdb->get_col($wpdb->prepare("SELECT id FROM $table_name WHERE status = 'new' AND object != '' AND object != 'not stored' AND form = %d", $form_id));
        } 
        elseif ( isset( $_REQUEST['page'] ) && ( $_REQUEST['page'] == 'sform-editing' || $_REQUEST['page'] == 'sform-settings' ) ) {
          $unread = $wpdb->get_col("SELECT id FROM $table_name WHERE status = 'new' AND object != '' AND object != 'not stored' AND form = '1'");
        } else {
          $unread = $wpdb->get_col("SELECT id FROM $table_name WHERE status = 'new' AND object != '' AND object != 'not stored' AND form != '0' AND listable = '1'");
        } 
        $real_count = isset( $_REQUEST['page'] ) && $_REQUEST['page'] == 'sform-entrie' && in_array($id, $unread) ? '1' : '0';
        $notification_count = count($unread) - $real_count;
        // Use transients instead of new query 
        $item = $notification_count ? sprintf(__('Contacts', 'simpleform') . ' <span id="unread-messages"><span class="sform awaiting-mod">%d</span></span>', $notification_count) : __('Contacts', 'simpleform') . ' <span id="unread-messages"></span>';
      else:
        $item = __('Contacts', 'simpleform');
      endif;
          
      return $item;

    }

   /**
	 * Add action links in the plugin meta row
	 *
	 * @since    1.4
	 */
	
    public function plugin_links( $plugin_actions, $plugin_file ){ 
     
     $new_actions = array();
     
	 if ( SIMPLEFORM_SUBMISSIONS_BASENAME === $plugin_file ) { 
     $new_actions['sform_settings'] = '<a href="' . menu_page_url( 'sform-submissions', false ) . '">' . __('Dashboard', 'simpleform') . '</a> | <a href="' . menu_page_url( 'sform-settings', false ) . '">' . __('Settings', 'simpleform') . '</a>';
	 }

     return array_merge( $new_actions, $plugin_actions );

    }
    
	/**
	 * When user is on a SimpleForm related admin page, display footer text.
	 *
	 * @since    1.4.1
	 */

	public function admin_footer($text) {
		
      $settings = get_option('sform_settings');
      $admin_notices = ! empty( $settings['admin_notices'] ) ? esc_attr($settings['admin_notices']) : 'false';	

	  if ( $admin_notices == 'false' ) {
		global $current_screen;
	    global $wpdb;
        $table_name = $wpdb->prefix . 'sform_submissions'; 
        $count_all = $wpdb->get_var("SELECT COUNT(id) FROM $table_name");

		if ( ! empty( $current_screen->id ) && strpos( $current_screen->id, 'sform' ) !== false && $count_all > 5 ) {
			$plugin = '<strong>SimpleForm</strong>';
			$url1  = '<a href="https://wordpress.org/support/plugin/simpleform/reviews/?filter=5#new-post" target="_blank" rel="noopener noreferrer">&#9733;&#9733;&#9733;&#9733;&#9733;</a>';
			$url2  = '<a href="https://wordpress.org/support/plugin/simpleform/reviews/?filter=5#new-post" target="_blank" rel="noopener noreferrer">WordPress.org</a>';
			$url3  = '<a href="https://wordpress.org/support/plugin/simpleform/" target="_blank" rel="noopener noreferrer">Forum</a>';
			/* translators: $1$s: SimpleForm plugin name; $2$s: WordPress.org review link; $3$s: WordPress.org review link; $4$s: WordPress.org support forum link. */
			$text = '<span id="footer-thankyou">' . sprintf( __( 'Do you like %1$s? Support its further development by leaving us a %2$s rating on %3$s. Found an issue or have a feature suggestion, please tell on %4$s. Thanks in advance!', 'simpleform-contact-form-submissions' ), $plugin, $url1, $url2, $url3 ) . '</span>';
		}
      }	  

      else { 
	      $wptext = sprintf( __( 'Thank you for creating with <a href="%s">WordPress</a>.' ), __( 'https://wordpress.org/' ));
	      $text = '<span id="footer-thankyou">'.$wptext.'</span>'; 
	  }	
        
	  return $text;
		
	}
	
    /**
	 * Add message in the plugin meta row if core plugin is missing
	 *
	 * @since    1.4.4
	 */
	
    public function plugin_meta( $plugin_meta, $file ) {

	  $plugin_file = 'simpleform/simpleform.php';
	  
      if ( ! file_exists( WP_PLUGIN_DIR . '/' . $plugin_file )  && strpos( $file, SIMPLEFORM_SUBMISSIONS_BASENAME ) !== false ) {

 	  $plugin_url =  __( 'https://wordpress.org/plugins/simpleform/' );
      $message = '<a href="'.esc_url($plugin_url).'" target="_blank" style="color: orangered !important;">' . __('Install the SimpleForm plugin to allow this addon to work', 'simpleform-contact-form-submissions' ) . '</a>';
	  $plugin_meta[] = $message;
	  
	  }
				
	  return $plugin_meta;

	}

    /**
	 * Add plugin upgrade notification
	 *
	 * @since    1.5
	 */
	
    public function upgrade_notification( $plugin_data, $new_data ) {

	  $plugin_file = 'simpleform/simpleform.php';	  
     
      if ( isset( $plugin_data['update'] ) && $plugin_data['update'] && file_exists( WP_PLUGIN_DIR . '/' . $plugin_file ) ) {

	    $simpleform_data = get_plugin_data( WP_PLUGIN_DIR.'/simpleform/simpleform.php');
	    $version = '<b>'. SIMPLEFORM_VERSION_REQUIRED .'</b>';
        $message = sprintf( __( 'The new version requires SimpleForm version %s or greater installed. Please update SimpleForm to make it work properly!', 'simpleform-contact-form-submissions' ), $version );

        if ( version_compare ( $simpleform_data['Version'], SIMPLEFORM_VERSION_REQUIRED, '<') ) {
          echo '<br><span style="margin-left:26px"><b>'.__( 'Upgrade Notice', 'simpleform-contact-form-submissions' ).':</b> '.$message.'</span>';
        }
        
      }

	}
	
	/**
	 * Remove all unnecessary parameters leaving the original URL used before performing an action
	 *
	 * @since    1.6
	 */
    
    public function url_cleanup() {
	    
      global $sform_submissions_page;
      $screen = get_current_screen();      
      if(!is_object($screen) || $screen->id != $sform_submissions_page)
      return;
      
      $sform_list_table = new SForms_Submissions_List_Table();
      $doaction = $sform_list_table->current_action();
      
      if ( $doaction ) {

		  $referer_url = wp_get_referer();
		  if ( ! $referer_url ) {
		  $referer_url = admin_url( 'admin.php?page=sform-submissions' );
	      }
	      
		  $referer_view = explode('&view=', $referer_url)[1];
		  $view = isset($referer_view) ? explode('&', $referer_view)[0] : 'inbox';
          $sform_list_table->prepare_items();
          if ( $view == 'inbox' ) { $filter_by_view = "status != 'trash' AND status != 'spam'"; }
          if ( $view == 'trash' ) { $filter_by_view = "status = 'trash'"; }
          if ( $view == 'new' ) { $filter_by_view = "status = 'new'"; }
          if ( $view == 'spam' ) { $filter_by_view = "status = 'spam'"; }
          $where = $sform_list_table->get_query_conditions();
          $placeholders = $sform_list_table->get_query_placeholders();
          global $wpdb;
          $count = $wpdb->get_var( $wpdb->prepare("SELECT COUNT(id) FROM {$wpdb->prefix}sform_submissions $where AND $filter_by_view", $placeholders ) );
          $paged = isset( $_REQUEST['paged'] ) ? absint($_REQUEST['paged']) : '1';        
          $per_page = $sform_list_table->get_items_per_page('edit_submission_per_page', 20);
          $total_pages = ceil( $count / $per_page );
          if ( $paged > $total_pages ) { $pagenum = $total_pages; } 
		  else { $pagenum = $paged; }

          $url = remove_query_arg( array('paged', 'action', 'action2', 'id', '_wpnonce', '_wp_http_referer'), $referer_url );
		  if ( $pagenum > '1')
       	  $url = add_query_arg( 'paged', $pagenum, $url );

          wp_redirect($url);
          exit(); 
      
      }
      
      if ( ! empty( $_REQUEST['_wp_http_referer'] ) && ! $doaction ) {
	       
	      $referer_url = wp_get_referer();
		  if ( ! $referer_url ) {
		  $referer_url = stripslashes($_SERVER['REQUEST_URI']);
	      }
  
	      $view_arg = explode('&view=', $referer_url)[1];
		  $referer_view = isset($view_arg) ? explode('&', $view_arg)[0] : 'inbox';
	      $view = $referer_view != 'inbox' ? '&view='.$referer_view : '';
	      $removed_args = array( 'action', 'action2', '_wp_http_referer', '_wpnonce' );
	      
	      if ( empty( $_REQUEST['date'] ) )
 	      $removed_args = array_merge($removed_args,array('date'));
         
 	      if ( empty( $_REQUEST['s'] ) )
 	      $removed_args = array_merge($removed_args,array('s'));

  	      if ( ! empty( $_REQUEST['paged'] ) && $_REQUEST['paged'] <= '1' )
 	      $removed_args = array_merge($removed_args,array('paged'));

          $url = remove_query_arg($removed_args, $_SERVER['REQUEST_URI']) . $view;
          wp_redirect($url);
          exit;
          
       } 
             
    }
    
    /**
	 * Add support links in the plugin meta row
	 *
	 * @since    1.6.2
	 */
	
    public function support_link( $plugin_meta, $file ) {

      if ( strpos( $file, SIMPLEFORM_SUBMISSIONS_BASENAME ) !== false ) {
		$plugin_meta[] = '<a href="https://wordpress.org/support/plugin/simpleform-contact-form-submissions/" target="_blank">'.__('Support', 'simpleform-contact-form-submissions').'</a>';
		}
		
	  return $plugin_meta;

	}    

}