<?php

/**
 * The class instantiated during the plugin activation.
 *
 * @since      1.0
 */

class SimpleForm_Submissions_Activator {

	/**
     * Run default functionality during plugin activation.
     *
     * @since    1.0
     */

    public static function activate($network_wide) {
	    
     if ( function_exists('is_multisite') && is_multisite() ) {
	  if($network_wide) {
        global $wpdb;
        $blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
        foreach ( $blog_ids as $blog_id ) {
         switch_to_blog( $blog_id );
         self::sform_submissions_settings();
         self::change_db();
         restore_current_blog();
        }
      } else {
         self::sform_submissions_settings();
         self::change_db();
      }
     } else {
        self::sform_submissions_settings();
        self::change_db();
     }
    
    }
    
    /**
     *  Save initial settings.
     *
     * @since    1.4
     */

    public static function sform_submissions_settings() {
	    
	   $main_settings = get_option('sform_settings');

       if( $main_settings ) {
	       	       
	      if ( isset($main_settings['data_storing']) && in_array($main_settings['data_storing'], array('true', 'false')) )
          return;

          $new_settings = array(
	             'data_storing' => 'true',
	             'ip_storing' => 'true',
                 'data_columns' => 'subject,firstname,message,mail,date',
                 'counter' => 'true',
                 'deleting_messages' => 'false',
          ); 
 	    
          $settings = array_merge($main_settings,$new_settings);
          update_option('sform_settings', $settings); 
          
          global $wpdb;
          $shortcodes_table = $wpdb->prefix . 'sform_shortcodes';
          if ( $result = $wpdb->get_results("SHOW TABLES LIKE '".$shortcodes_table."'") ) {
             $ids = $wpdb->get_col("SELECT id FROM `$shortcodes_table` WHERE id != '1'");	
             if ( $ids ) {
	          foreach ( $ids as $id ) {
	          $old_form_settings = get_option('sform_'.$id.'_settings');
              if ( $old_form_settings != false ) {
              $form_settings = array_merge($old_form_settings,$new_settings);
              update_option('sform_'.$id.'_settings', $form_settings); 
              }
              }
             }
          }             

       }
              
    }

    /**
     * Modifies the database table.
     *
     * @since    1.0
     */
 
    public static function change_db() {

        $current_version = SIMPLEFORM_SUBMISSIONS_DB_VERSION;
        $installed_version = get_option('sform_sub_db_version');
       
        if ( $installed_version != $current_version ) {
        
        global $wpdb;
        $charset_collate = $wpdb->get_charset_collate();
        $prefix = $wpdb->prefix;
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	        
          $submissions_table = $prefix . 'sform_submissions';
          $sql = "CREATE TABLE " . $submissions_table . " (
            id int(11) NOT NULL AUTO_INCREMENT,
            form int(7) NOT NULL DEFAULT 1,
            requester_type tinytext NOT NULL,
            requester_id int(15) NOT NULL,
            name tinytext NOT NULL,
            lastname tinytext NOT NULL,
            email VARCHAR(200) NOT NULL,
            ip VARCHAR(128) NOT NULL,	
            phone VARCHAR(50) NOT NULL,
            subject tinytext NOT NULL,
            object text NOT NULL,
            date datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
            status tinytext NOT NULL,
            trash_date datetime NOT NULL,
            notes text NOT NULL,
            listable tinyint(1) NOT NULL DEFAULT 1,
           PRIMARY KEY  (id)
          ) ". $charset_collate .";";
          dbDelta($sql);
          update_option('sform_sub_db_version', $current_version);
        }
   
    }
    
    /**
     *  Create a table whenever a new blog is created in a WordPress Multisite installation.
     *
     * @since    1.0
     */

    public static function on_create_blog($params) {
       
       if ( is_plugin_active_for_network( 'simpleform-submissions/simpleform-submissions.php' ) ) {
       switch_to_blog( $params->blog_id );
       self::sform_submissions_settings();
       self::change_db();
       restore_current_blog();
       }

    }    
  
}